Copulalib
Description: usage page of the Copulalib
Keywords: copula, AMBHAS

# Examples

One simple examle to estimate the NDVI and DVI from the R, G, NIR, SWIR data.

    >>> from vilib.vilib import vi
    >>> g = np.random.randn(100)
    >>> r = np.random.randn(100)
    >>> nir = np.random.randn(100)
    >>> swir = np.random.randn(100)
    >>> foo = vi(g,r,nir,swir)
    >>> ndvi = foo.get_vi('ndvi')   # calculate the NDVI
    >>> dvi = foo.get_vi('dvi')     # calculate the DVI